@@ -58,3 +58,7 @@ register_option(CONF_RIKAI_IMAGE_DEFAULT_FORMAT, DEFAULT_IMAGE_DEFAULT_FORMAT)
 CONF_RIKAI_IO_HTTP_AGENT = "rikai.io.http_agent"
 DEFAULT_RIKAI_IO_HTTP_AGENT = f"rikai/{_rikai_version}"
 register_option(CONF_RIKAI_IO_HTTP_AGENT, DEFAULT_RIKAI_IO_HTTP_AGENT)
+
+CONF_RIKAI_VIZ_COLOR = "rikai.viz.color"
+DEFAULT_RIKAI_VIZ_COLOR = "red"
+register_option(CONF_RIKAI_VIZ_COLOR, DEFAULT_RIKAI_VIZ_COLOR)
